@@ -1,57 +1,24 @@
 package jp.ac.takushoku_u.cs;
 
 /**
-* Matrix饹Ǥϥޥȥꥯ򰷤ޤ<BR>
+* Matrix饹ǤdoubleǤĥޥȥꥯ򰷤ޤ<BR>
 * ޥȥꥯʬϥǡ̾̾դݻǤ褦ˤʤޤ
 * ޤޥȥꥯƱΤα黻ԤȤǤޤ<BR>
-* @version 1.1
+* @version 1.21
 * @author  ͵(Kasajima Hiroshi)
+* @see jp.ac.takushoku_u.cs.BooleanMatrix
+* @see jp.ac.takushoku_u.cs.StringMatrix
 */
 /*
-* ǽ 2004ǯ0928
+* ǽ 2004ǯ1103
 */
-public class Matrix{
-
-/**
-* ԤΥݻѿ
-*/
-    private int matrixRowSize;
-	
-/**
-* Υݻѿ
-*/
-	private int matrixColSize;
-	
-/**
-* ޥȥꥯγǤΥǡǼ2
-*/
-    private double[ ][ ] matrix;
-	
-/**
-* ̾Ǽ
-*/
-	private String[ ] matrixRowName;
-	
-/**
-* ̾Ǽ
-*/
-	private String[ ] matrixColName;
+public class Matrix extends BasicMatrix{
 	
 /**
 * ޥȥꥯ򥯥ꥢȤ͡
 */
 	private static final double MATRIX_CLEAR_VALUE = 0.0;
 	
-/**
-* 2ιԥΥǥե͡
-*/
-	private static final int MATRIX_INIT_ROW_SIZE = 5;
-	
-/**
-* 2󥵥Υǥե͡
-*/
-	private static final int MATRIX_INIT_COL_SIZE = 5;
-	
 /**
 * False͡
 */
@@ -69,10 +36,8 @@ public class Matrix{
 * ̾̾Ϲֹֹꤵޤ
 */
 	public Matrix(){
-		setSizeMatrix(MATRIX_INIT_ROW_SIZE,MATRIX_INIT_COL_SIZE);
+		super();
 		clearMatrix();
-		setRowNameNumber();
-		setColNameNumber();
 	}
 
 /**
@@ -84,10 +49,8 @@ public class Matrix{
 * @exception NegativeMatrixSizeException ΥΥޥȥꥯ褦Ȥ
 */
 	public Matrix(int rowSize, int colSize){
-		setSizeMatrix(rowSize,colSize);
+		super(rowSize, colSize);
 		clearMatrix();
-		setRowNameNumber();
-		setColNameNumber();
 	}
 	
 /**
@@ -101,10 +64,8 @@ public class Matrix{
 * @exception NegativeMatrixSizeException ΥΥޥȥꥯ褦Ȥ
 */
 	public Matrix(int rowSize, int colSize, int nameNumber){
-		setSizeMatrix(rowSize,colSize);
+		super(rowSize, colSize, nameNumber);
 		clearMatrix();
-		setRowNameNumber(nameNumber);
-		setColNameNumber(nameNumber);
 	}
 	
 /**
@@ -119,12 +80,12 @@ public class Matrix{
 * @exception NullPointerException  rowName ޤ colName  null ξ
 */
 	public Matrix(int rowSize, int colSize, String[] rowName, String[] colName){
-		setSizeMatrix(rowSize, colSize);
+		super(rowSize, colSize);
 		clearMatrix();
 		
 		//̾̾Υԡ
-		System.arraycopy(rowName, 0, matrixRowName, 0, rowName.length);
-		System.arraycopy(colName, 0, matrixColName, 0, colName.length);
+		nameRowCopy(rowName);
+		nameColCopy(colName);
 	}
 	
 /**
@@ -135,14 +96,14 @@ public class Matrix{
 * @exception NullPointerException  originalMatrix  null ξ
 */
 	public Matrix(double[][] originalMatrix){
-		setSizeMatrix(originalMatrix.length, originalMatrix[0].length);
+		super(originalMatrix.length, originalMatrix[0].length);
 		
 		//ޥȥꥯΥԡ
-		for (int i = 0; i < originalMatrix.length; i++){
-			System.arraycopy(originalMatrix[i], 0, matrix[i], 0, originalMatrix[i].length);
+		for (int i = 0; i < getRowLength(); i++){
+			for (int j = 0; j < getColLength(); j++){
+				setCell(i, j, originalMatrix[i][j]);
+			}
 		}
-		setRowNameNumber();
-		setColNameNumber();
 	}
 
 /**
@@ -155,14 +116,14 @@ public class Matrix{
 * @exception NullPointerException  originalMatrix  null ξ
 */
 	public Matrix(double[][] originalMatrix, int nameNumber){
-		setSizeMatrix(originalMatrix.length, originalMatrix[0].length);
+		super(originalMatrix.length, originalMatrix[0].length, nameNumber);
 		
 		//ޥȥꥯΥԡ
-		for(int i = 0; i < originalMatrix.length; i++){
-			System.arraycopy(originalMatrix[i], 0, matrix[i], 0, originalMatrix[i].length);
+		for (int i = 0; i < getRowLength(); i++){
+			for (int j = 0; j < getColLength(); j++){
+				setCell(i, j, originalMatrix[i][j]);
+			}
 		}
-		setRowNameNumber(nameNumber);
-		setColNameNumber(nameNumber);
 	}
 
 /**
@@ -174,19 +135,51 @@ public class Matrix{
 * @exception NullPointerException  rowName , colName ޤ originalMatrix  null ξ
 */
 	public Matrix(double[][] originalMatrix, String[] rowName, String[] colName){
-		setSizeMatrix(originalMatrix.length, originalMatrix[0].length);
+		super(originalMatrix.length, originalMatrix[0].length);
 		
 		//ޥȥꥯΥԡ
-		for (int i = 0; i < originalMatrix.length; i++){
-			System.arraycopy(originalMatrix[i], 0, matrix[i], 0, originalMatrix[i].length);
+		for (int i = 0; i < getRowLength(); i++){
+			for (int j = 0; j < getColLength(); j++){
+				setCell(i, j, originalMatrix[i][j]);
+			}
 		}
 		
 		//̾̾Υԡ
-		System.arraycopy(rowName, 0, matrixRowName, 0, rowName.length);
-		System.arraycopy(colName, 0, matrixColName, 0, colName.length);
+		nameRowCopy(rowName);
+		nameColCopy(colName);
 	}
 
-
+/**
+* ݻ줿Ǥѹ˥ޥȥꥯ礭ѹޤ
+* ޥȥꥯ򾮤ϻꤷǤ礭ʬʤʤޤ
+* 礭礭줿ʬϽͤǽ졢
+* ̾̾Ϥ줾ֹֹˤʤޤ
+* @param rowLength ԥ
+* @param colLength 󥵥
+* @exception NegativeMatrixSizeException ΥΥޥȥꥯ褦Ȥ
+*/
+	public void reSizeMatrix(int rowLength, int colLength){
+		int r = getRowLength();
+		int c = getColLength();
+		super.reSizeMatrix(rowLength, colLength);
+		
+		
+		//ޥȥꥯǤ
+		for (int i = 0; i < rowLength; i++){
+			if(i >= r){
+				setRowName(i, i+"");
+			}
+			for (int j = 0; j < colLength; j++){
+				if(j >= c){
+					setColName(j, j+"");
+				}
+				if((i >= r) || (j >= c)){
+					setCell(i, j, MATRIX_CLEAR_VALUE);
+				}
+			}
+		}
+	}
+	
 /**
 * ꤵ줿1ͤꤷޤ
 * @param row ֹ
@@ -196,7 +189,8 @@ public class Matrix{
 */
 	public void setCell(int row,int col,double value){
 		if (isMatrixEntityPoint(row, col)){
-			matrix[row][col] = value;
+			Double d = new Double(value);
+			super.setCell(row, col, d);
 		}
 		else{
 			throw new NotElementException("Point(" + row + "," + col + ")");
@@ -207,26 +201,10 @@ public class Matrix{
 * ޥȥꥯ¾Υޥȥꥯǡ̾̾Ƥ򥳥ԡޤ<BR>
 * ԡΥޥȥꥯȰפʤϥԡΥޥȥꥯѹԡԤޤ
 * @param originalMatrix ԡΥޥȥꥯ
-* @see #MatrixElementCopy(Matrix originalMatrix, int baseRow, int baseCol, int copyRow,int copyCol, int rowLength, int colLength)
+* @see #MatrixCopy(Matrix originalMatrix, int baseRow, int baseCol, int copyRow,int copyCol, int rowLength, int colLength)
 */
 	public void MatrixCopy(Matrix originalMatrix){
-		
-		//ǧפʤϥѹޤ
-		if ((getRowLength() != originalMatrix.getRowLength()) ||
-			(getColLength() != originalMatrix.getColLength())){
-				setSizeMatrix(originalMatrix.getRowLength(), originalMatrix.getColLength());
-		}
-		
-		//ԡ򤷤ޤ
-			for (int i = 0; i < getRowLength(); i++){
-				setRowName(i, originalMatrix.getRowName(i));
-				for (int j = 0; j < getColLength(); j++){
-					if (i == 0){
-						setColName(j, originalMatrix.getColName(j));
-					}
-					setCell(i, j, originalMatrix.getCell(i, j));
-				}
-			}
+		super.MatrixCopy(originalMatrix);
 	}
 	
 /**
@@ -244,69 +222,23 @@ public class Matrix{
 * @exception SetValueOutOfBoundsException ԡ褬¸ߤʤϰϤˤ
 * @see #MatrixCopy(Matrix originalMatrix)
 */
-	public void MatrixElementCopy(Matrix originalMatrix, int baseRow, int baseCol, int copyRow,
+	public void MatrixCopy(Matrix originalMatrix, int baseRow, int baseCol, int copyRow,
 		int copyCol, int rowLength, int colLength){
-		
-		//ԡΥǧޤ
-		if ((getRowLength() - copyRow >= rowLength) &&
-			(getColLength() - copyCol >= colLength) &&
-			(originalMatrix.getRowLength() >= (rowLength + baseRow)) &&
-			(originalMatrix.getColLength() >= (colLength + baseCol))){
-			for (int i = 0 + copyRow; i < copyRow + rowLength; i++){
-				for (int j = 0 + copyCol; j < copyCol + colLength; j++){
-					setCell(i, j, originalMatrix.getCell(i, j));
-				}
-			}
-		}
-		else{
-			throw new SetValueOutOfBoundsException();
-		}
+			super.MatrixCopy(originalMatrix, baseRow, baseCol, copyRow,
+				copyCol, rowLength, colLength);
 	}
 	
 /**
 * ޥȥꥯ¸ߤǤ0ˤޤ
 */
 	public void clearMatrix(){
-		for (int i = 0 ; i < matrixRowSize ; i++){
-			for (int j = 0 ; j < matrixColSize ; j++){
+		for (int i = 0 ; i < getRowLength() ; i++){
+			for (int j = 0 ; j < getColLength() ; j++){
 				setCell(i, j, MATRIX_CLEAR_VALUE);
 			}
 		}
 	}
 	
-/**
-* Ԥι̾դޤ
-* @param row ֹ
-* @param rowName ̾
-* @exception NotElementException ꤵ줿Ԥ¸ߤʤ
-* @see #setColName(int col,String colName)
-*/
-	public void setRowName(int row,String rowName){
-		if (isRowNumber(row)){
-			matrixRowName[row] = rowName;
-		}
-		else{
-			throw new NotElementException("row("+ row + ")");
-		}
-	}
-	
-/**
-* ̾դޤ
-* @param col ֹ
-* @param colName ̾
-* @exception NotElementException ꤵ줿¸ߤʤ
-* @see #setRowName(int row,String rowName)
-*/
-	public void setColName(int col,String colName){
-		if (isColNumber(col)){
-			matrixColName[col] = colName;
-		}
-		else{
-			throw new NotElementException("col("+ col+")");
-		}
-	}
-	
-	
 /**
 * ꤵ줿1֤ͤޤ
 * @param row ֹ
@@ -316,31 +248,17 @@ public class Matrix{
 */
 	public double getCell(int row, int col){
 		if (isMatrixEntityPoint(row, col)){
-			return matrix[row][col];
+			Double d = new Double(0.0);
+			d = (Double)getObjectCell(row,col);
+			double b = d.doubleValue();
+			return b;
+			//return matrix[row][col];
 		}
 		else{
 			throw new NotElementException("point(" + row + "," + col + ")");
 		}
 	}
 	
-/**
-* ޥȥꥯιԥ֤ޤ
-* @return ԥ
-* @see #getColLength()
-*/
-	public int getRowLength(){
-		return matrixRowSize;
-	}
-	
-/**
-* ޥȥꥯ󥵥֤ޤ
-* @return 󥵥
-* @see #getRowLength()
-*/
-	public int getColLength(){
-		return matrixColSize;
-	}
-	
 /**
 * ꤷԤˤͤιפ֤ޤ
 * @param row ֹ
@@ -494,104 +412,6 @@ public class Matrix{
 		return maxValue;
 	}
 	
-/**
-* ꤷԤι֤̾ޤ
-* @param  row 
-* @return Ԥι̾
-* @exception NotElementException ꤵ줿Ԥ¸ߤʤ
-* @see #getColName(int col)
-* @see #getRowNameArray()
-*/
-	public String getRowName(int row){
-		if (isRowNumber(row)){
-			return matrixRowName[row];
-		}
-		else{
-			throw new NotElementException("row("+ row +")");
-		}
-	}
-	
-/**
-* ޥȥꥯˤƤι֤̾ޤ
-* @return ̾ä
-* @see #getColNameArray()
-* @see #getRowName(int row)
-*/
-	public String[] getRowNameArray(){
-		String[] returnArray = new String[getRowLength()];
-		for (int i = 0; i < getRowLength(); i++){
-			returnArray[i] = getRowName(i);
-		}
-		return returnArray;
-	}
-	
-/**
-* ꤷι֤̾ޤ
-* @param  col 
-* @return Ԥ̾
-* @exception NotElementException ꤵ줿¸ߤʤ
-* @see #getRowName(int row)
-* @see #getColNameArray()
-*/
-	public String getColName(int col){
-		if (isColNumber(col)){
-			return matrixColName[col];
-		}
-		else{
-			throw new NotElementException("col("+ col +")");
-		}
-	}
-	
-/**
-* ޥȥꥯˤƤ֤̾ޤ
-* @return ̾ä
-* @see #getRowNameArray()
-* @see #getColName(int col)
-*/
-	public String[] getColNameArray(){
-		String[] returnArray = new String[getColLength()];
-		for (int i = 0; i < getColLength(); i++){
-			returnArray[i] = getColName(i);
-		}
-		return returnArray;
-	}
-	
-/**
-* ꤷ̾ιֹ֤ޤ
-* @param rowName ̾
-* @return Ԥιֹ
-* @exception NotElementException ꤵ줿̾¸ߤʤ
-* @see #getColNumber(String colName)
-*/
-	public int getRowNumber(String rowName){
-		for (int i = 0; i < getRowLength(); i++){
-			if (rowName.equals(matrixRowName[i])){
-				return i;
-			}
-		}
-		
-		//¸ߤʤ
-		throw new NotElementException("rowName(" + rowName + ")");
-	}
-	
-/**
-* ꤷֹ֤̾ޤ
-* @param colName ̾
-* @return Ԥֹ
-* @exception NotElementException ꤷ̾¸ߤʤ
-* @see #getRowNumber(String rowName)
-*/
-	public int getColNumber(String colName){
-		for (int i = 0; i < getColLength(); i++){
-			if (colName.equals(matrixColName[i])){
-				return i;
-			}
-		}
-		
-		//¸ߤʤ
-		throw new NotElementException("colName(" + colName + ")");
-	}
-	
 /**
 * ޥȥꥯ¸ߤǤΤǤ0ĶǤο֤ޤ
 * @return ǿ
@@ -608,107 +428,6 @@ public class Matrix{
 		return element;
 	}
 	
-/**
-* ޥȥꥯ˻ꤷǤ¸ߤ뤫åޤ
-* @param row ֹ
-* @param col ֹ
-* @return Υޥȥꥯ˻ꤷǤ¸ߤtrue¸ߤʤfalse֤ޤ
-*/
-	public boolean isMatrixEntityPoint(int row,int col){
-		return ((0 <= row && row < this.getRowLength()) &&
-			(0 <= col && col < this.getColLength()));
-	}
-
-/**
-* ޥȥꥯ˻ꤷֹ椬¸ߤ뤫åޤ
-* @param row ֹ
-* @return Υޥȥꥯ˻ꤷֹ椬¸ߤtrue¸ߤʤfalse֤ޤ
-*/
-	public boolean isRowNumber(int row){
-		return ((0 <= row) && (row < this.getRowLength()));
-	}
-	
-/**
-* ޥȥꥯ˻ꤷֹ椬¸ߤ뤫åޤ
-* @param col ֹ
-* @return Υޥȥꥯ˻ꤷֹ椬¸ߤtrue¸ߤʤfalse֤ޤ
-*/
-	public boolean isColNumber(int col){
-		return ((0 <= col) && (col < this.getColLength()));
-	}
-	
-/**
-* 2Ǥ礭ѹޤ
-* @param rowSize ԥ
-* @param colSize 󥵥
-* @exception NegativeMatrixSizeException ΥΥޥȥꥯ褦Ȥ
-*/
-	private void setSizeMatrix(int rowSize, int colSize){
-		
-		//ǤϤʤ
-		if((rowSize >= 0) && ( colSize >= 0)){
-			matrix = new double[rowSize][colSize];		//ǡ¸Ѥ2
-			matrixRowSize = rowSize;		//ԥ
-			matrixColSize = colSize;		//󥵥
-			matrixRowName = new String[matrixRowSize];		//̾
-			matrixColName = new String[matrixColSize];		//̾
-		}
-		else{
-			throw new NegativeMatrixSizeException();
-		}
-	}
-	
-/**
-* ̾˹ֹ̾Ȥꤷޤ<BR>
-* ֹ0Ϥޤ뤿ᡢ0˹ֹ̾椬ƱֹȤʤޤ 
-* @see #setColNameNumber()
-* @see #setRowNameNumber(int start)
-*/
-	public void setRowNameNumber(){
-		for (int i = 0; i < getRowLength(); i++){
-			setRowName(i, i +"");
-		}
-	}
-	
-/**
-* ̾startϤޤֹ̾Ȥꤷޤ
-* @param start ǽιֹ̾
-* @see #setColNameNumber(int start)
-* @see #setRowNameNumber()
-*/
-	public void setRowNameNumber(int start){
-		for (int i = 0; i < getRowLength(); i++){
-			setRowName(i, i + start +"");
-		}
-	}
-	
-/**
-* ֹ̾̾Ȥꤷޤ<BR>
-* ֹ0Ϥޤ뤿ᡢ0ֹ̾椬ƱֹȤʤޤ 
-* @see #setRowNameNumber()
-* @see #setColNameNumber(int start)
-*/
-	public void setColNameNumber(){
-		for (int i = 0; i < getColLength(); i++){
-			setColName(i, i +"");
-		}
-	}
-	
-/**
-* ̾startϤޤֹ̾Ȥꤷޤ
-* @param start ǽֹ̾
-* @see #setRowNameNumber(int start)
-* @see #setColNameNumber()
-*/
-	public void setColNameNumber(int start){
-		for (int i = 0; i < getColLength(); i++){
-			setColName(i, i + start +"");
-		}
-	}
-	
-
-	
-	
 /**
 * ޥȥꥯǤ012ͤѴޤ
 * 0ʲο0ˡ0ۤ1Ѵޤ
@@ -725,6 +444,86 @@ public class Matrix{
 			}
 		}
 	}
+
+/**
+* MatrixBooleanMatrixѴޤ
+* 0ʲοfalseˡ0ۤtrueȤޤ
+* Ѵ줿ޥȥꥯˤϹ̾̾ϰѤޤ
+* @return Ѵ줿ޥȥꥯ
+* @see #toBooleanMatrix(double value)
+* @see #toStringMatrix()
+*/
+	public BooleanMatrix toBooleanMatrix(){
+		BooleanMatrix returnMatrix = new BooleanMatrix(getRowLength(), getColLength(),
+			getRowNameArray(), getColNameArray());
+			for (int i = 0; i < getRowLength(); i++){
+				for (int j = 0; j < getColLength(); j++){
+					if (getCell(i, j) <= 0){
+						returnMatrix.setCell(i, j, false);
+					}
+					else{
+						returnMatrix.setCell(i, j, true);
+					}
+				}
+			}
+		return returnMatrix;
+	}
+	
+/**
+* MatrixBooleanMatrixѴޤ
+*  value ʲοfalseˡ value ۤtrueȤޤ<BR>
+* âͤ0ξϡ0falseˡ0ʳοtrueȤޤ
+* 0ʲοfalseȤtoBooleanMatrix()ѤƤ
+* Ѵ줿ޥȥꥯˤϹ̾̾ϰѤޤ
+* @param value 
+* @return Ѵ줿ޥȥꥯ
+* @see #toBooleanMatrix()
+* @see #toStringMatrix()
+*/
+	public BooleanMatrix toBooleanMatrix(double value){
+		BooleanMatrix returnMatrix = new BooleanMatrix(getRowLength(), getColLength(),
+			getRowNameArray(), getColNameArray());
+		for (int i = 0; i < getRowLength(); i++){
+			for (int j = 0; j < getColLength(); j++){
+				if(value != 0){
+					if (getCell(i, j) <= value){
+						returnMatrix.setCell(i, j, false);
+					}
+					else{
+						returnMatrix.setCell(i, j, true);
+					}
+				}
+				else{
+					if (getCell(i, j) == value){
+						returnMatrix.setCell(i, j, false);
+					}
+					else{
+						returnMatrix.setCell(i, j, true);
+					}
+				}
+			}
+		}
+		return returnMatrix;
+	}
+	
+/**
+* MatrixStringMatrixѴޤ
+* Ǥͤ򤽤ΤޤʸȤޤ
+* Ѵ줿ޥȥꥯˤϹ̾̾ϰѤޤ
+* @return Ѵ줿Matrix
+* @see #toBooleanMatrix()
+* @see #toBooleanMatrix(double value)
+*/
+	public StringMatrix toStringMatrix(){
+		StringMatrix returnMatrix = new StringMatrix(getRowLength(), getColLength(),
+			getRowNameArray(), getColNameArray());
+		for (int i = 0; i < getRowLength(); i++){
+			for (int j = 0; j < getColLength(); j++){
+					returnMatrix.setCell(i, j, Double.toString(getCell(i, j)));
+			}
+		}
+		return returnMatrix;
+	}
 	
 /**
 * 2ĤΥޥȥꥯΥƱåޤ
@@ -745,14 +544,6 @@ public class Matrix{
 		return getColLength() == compareMatrix.getRowLength();
 	}
 	
-/**
-* Υޥȥꥯ󤫥åޤ
-* @return ʤTrue򡢰㤦False֤ޤ
-*/
-	public boolean isSquare(){
-		return getRowLength() == getColLength();
-	}
-	
 /**
 * ¾ΥޥȥꥯȤ(And)֤ޤ<BR>
 * α黻˹ԤäconvertLogicMatrix᥽åɤ¹Ԥޤ
@@ -898,11 +689,61 @@ public class Matrix{
 	}
 	
 /**
-* ޥȥꥯƱΤѤ֤ޤ<BR>
+* ޥȥꥯvalueܤޥȥꥯ֤ޤ
+* ޥȥꥯƤǤФơvalueܤޥȥꥯ֤ޤ
+* @param value ݤ
+* @return valueܤ줿ޥȥꥯ
+* @see #getMultiplyMatrix(Matrix calculateMatrix)
+*/
+	public Matrix getTimesMatrix(double value){
+		Matrix returnMatrix = new Matrix(getRowLength(), getColLength(),
+			getRowNameArray(), getColNameArray());
+		for(int i = 0; i < getRowLength(); i++){
+			for(int j = 0; j < getColLength(); j++){
+				double v = value * getCell(i, j);
+				returnMatrix.setCell(i, j, v);
+			}
+		}
+		return returnMatrix;
+	}
+	
+/**
+* ޥȥꥯƱΤ¤׻ޥȥꥯ֤ޤ<BR>
+* ֤ޥȥꥯι̾̾ϥޥȥꥯƱΤȤʤޤ
+* @param calculateMatrix ûоݤΥޥȥꥯ
+* @return 黻̤Υޥȥꥯ
+* @exception DisagreementMatrixSizeException 黻Ԥ2ĤΥޥȥꥯΥפʤ
+*/
+	public Matrix getAddMatrix(Matrix calculateMatrix){
+		Matrix returnMatrix = new Matrix(getRowLength(), getColLength(),
+			getRowNameArray(), calculateMatrix.getColNameArray());
+		
+		//黻Ԥ뤫ɤ
+		if (isSameMatrixSize(calculateMatrix)){
+			for (int i = 0; i < returnMatrix.getRowLength(); i++){
+				for (int j = 0; j < returnMatrix.getColLength(); j++){
+					double value = 0.0;
+					value = getCell(i, j) + calculateMatrix.getCell(i, j);
+					returnMatrix.setCell(i, j, value);
+				}
+			}
+		}
+		
+		//黻Ԥʤ
+		else{
+			throw new DisagreementMatrixSizeException();
+		}
+			return returnMatrix;
+	}
+	
+/**
+* ޥȥꥯƱΤѤ׻ޥȥꥯ֤ޤ<BR>
+* 黻 ޥȥꥯ  calculateMatrix ǹԤޤ
 * ֤ޥȥꥯΥϱ黻Υޥȥꥯιԥ߱黻оݤΥޥȥꥯ󥵥Ȥʤޤ
 * @param calculateMatrix 軻оݤΥޥȥꥯ
 * @return 黻̤Υޥȥꥯ
 * @exception DisagreementMatrixSizeException 黻Ԥ2ĤΥޥȥꥯΥ黻Ԥʤξ
+* @see #getTimesMatrix(double value)
 */
 	public Matrix getMultiplyMatrix(Matrix calculateMatrix){
 		Matrix returnMatrix = new Matrix(getRowLength(), calculateMatrix.getColLength(),
@@ -939,8 +780,8 @@ public class Matrix{
 * @exception NotSquareMatrixException ޥȥꥯǤʤ
 */
 	public Matrix getExponentMatrix(int exponent){
-		Matrix initMatrix = new Matrix(matrix, getRowNameArray(), getColNameArray());
-		Matrix returnMatrix = new Matrix(matrix, getRowNameArray(), getColNameArray());
+		Matrix initMatrix = new Matrix(getMatrix(), getRowNameArray(), getColNameArray());
+		Matrix returnMatrix = new Matrix(getMatrix(), getRowNameArray(), getColNameArray());
 		
 		//󤫤ɤޤؿ0ʲͤꤵ줿
 		if (isSquare()){
@@ -968,7 +809,7 @@ public class Matrix{
 	}
 	
 /**
-* ޥȥꥯǤñ̹ˤޤ
+* ޥȥꥯǤñ̥ޥȥꥯѹޤ
 * @exception NotSquareMatrixException ޥȥꥯǤʤ
 */
 	public void createElementaryMatrix(){
@@ -994,7 +835,7 @@ public class Matrix{
 	}
 	
 /**
-* ΥޥȥꥯƱñ̹ޤ
+* ΥޥȥꥯƱñ̥ޥȥꥯ֤ޤ
 * @return ñ̹
 */
 	private Matrix getElementaryMatrix(){
@@ -1016,7 +857,7 @@ public class Matrix{
 		//󤫤ɤ
 		if (isSquare()){
 		//ΥޥȥꥯܥޥȥꥯȤ
-		Matrix returnMatrix = new Matrix(matrix, getRowNameArray(), getColNameArray());
+		Matrix returnMatrix = new Matrix(getMatrix(), getRowNameArray(), getColNameArray());
 		
 		//ͤΥޥȥꥯѴ
 		returnMatrix.convertLogicMatrix();
@@ -1037,60 +878,38 @@ public class Matrix{
 		}
 	}
 	
-	
-//ʲƥѥ᥽å
-/*
 /**
-* ޥȥꥯintɸϤ˽Ϥޤ
-
-	public void outputIntMatrix(){
-		System.out.print("       ");
-		for (int j = 0; j < getColLength(); j++){		//̾
-			System.out.print(getColName(j) + " ");
-		}
-		System.out.println();
-		for (int i = 0 ; i < getRowLength(); i++){
-			if (i < 9){
-			System.out.print(getRowName(i) + " ");		//̾
-			}
-			else{
-				System.out.print(getRowName(i) + " ");
-			}
-			for (int j = 0; j < getColLength(); j++){		//ǽ
-				if (j == (getColLength() - 1)){
-					System.out.println("     "+(int)getCell(i, j));
-				}
-				else{
-					System.out.print("     "+(int)getCell(i, j));
-				}
+* ޥȥꥯž֥ޥȥꥯ֤ޤ
+* ֤줿ޥȥꥯι̾̾Ϥ줾줬ؤäΡʹ̾̾̾̾ˡˤˤʤޤ
+* @return ž֥ޥȥꥯ
+*/
+	public Matrix getTransposedMatrix(){
+		Matrix returnMatrix = new Matrix(getColLength(), getRowLength(),
+			getColNameArray(), getRowNameArray());
+		for(int i = 0; i < returnMatrix.getRowLength(); i++){
+			for(int j = 0; j < returnMatrix.getColLength(); j++){
+				returnMatrix.setCell(i, j, getCell(j, i));
 			}
 		}
-		System.out.println();
+		return returnMatrix;
 	}
 	
 /**
-* ޥȥꥯdoubleɸϤ˽Ϥޤ
-
-	public void outputDoubleMatrix(){
-		java.text.NumberFormat df = new java.text.DecimalFormat("0.000");		//ʲ3ޤǽ
-		System.out.print("       ");
-		for (int j = 0; j < getColLength(); j++){
-			System.out.print(getColName(j) + " ");		//̾
-		}
-		System.out.println();
-		for (int i = 0 ; i < getRowLength(); i++){
-			System.out.print(getRowName(i) + "  ");		//̾
-			for (int j = 0; j < getColLength(); j++){		//ǽ
-				if (j == (getColLength() - 1)){
-					System.out.println(df.format(getCell(i, j)));
-				}
-				else{
-					System.out.print(df.format(getCell(i, j) )+" ");
-				}
+* ޥȥꥯǤ2֤ޤ
+* @return Ǥ2
+*/
+	public double[][] getMatrix(){
+		Double d[][] = new Double[getRowLength()][getColLength()];
+		double dou[][] = new double[getRowLength()][getColLength()];
+		Object o[][] = new Object[getRowLength()][getColLength()];
+		o = getObjectMatrix();
+		for(int i=0; i < getRowLength(); i++){
+			for(int j=0; j < getColLength(); j++){
+				d[i][j] = (Double)o[i][j];
+				dou[i][j] = d[i][j].doubleValue();
 			}
 		}
-		System.out.println();
+		return dou;
 	}
-	*/
 	
 }
\ No newline at end of file
