@@ -6,7 +6,7 @@ package jp.ac.takushoku_u.cs;
 * @author  ͵(Kasajima Hiroshi)
 */
 /*
-* ǽ 2004ǯ1006
+* ǽ 2004ǯ1029
 */
 public class SPTable{
 	
@@ -134,7 +134,7 @@ public class SPTable{
 		spMatrix.MatrixCopy(getSPMatrix());
 		
 		//S-PɽΥԡ
-		spFullMatrix.MatrixElementCopy(spMatrix, 0, 0, 0, 0, spMatrix.getRowLength(), spMatrix.getColLength());
+		spFullMatrix.MatrixCopy(spMatrix, 0, 0, 0, 0, spMatrix.getRowLength(), spMatrix.getColLength());
 		
 		//¦ν
 		for(int i = 0; i < spMatrix.getRowLength(); i++){
@@ -837,7 +837,7 @@ public class SPTable{
 	
 /**
 * ꤷS-PɽΥޥȥꥯǤϲܤˤ뤫ֹ֤ޤ
-* @param row ɽˤֹ
+* @param col ɽˤֹ
 * @return S-Pɽˤֹ
 * @exception NotElementException ꤵ줿ֹ椬¸ߤʤ
 */
@@ -854,11 +854,11 @@ public class SPTable{
 	
 /**
 * S-PɽΥޥȥꥯꤷޤ
-* @param _baseMatrix Ԥޥȥꥯ
+* @param baseMatrix Ԥޥȥꥯ
 */
-	private void setBaseMatrix(Matrix _baseMatrix){
-		matrix = new Matrix(_baseMatrix.getRowLength(), _baseMatrix.getColLength());
-		matrix.MatrixCopy(_baseMatrix);
+	private void setBaseMatrix(Matrix baseMatrix){
+		matrix = new Matrix(baseMatrix.getRowLength(), baseMatrix.getColLength());
+		matrix.MatrixCopy(baseMatrix);
 	}
 	
 /**
